@@ -49,6 +49,13 @@ class MarkdownInput(Textarea):
     class Media:
         js = (
             '//cdnjs.cloudflare.com/ajax/libs/marked/0.2.9/marked.min.js',
+            '//cdnjs.cloudflare.com/ajax/libs/ekko-lightbox/3.0.3a/ekko-lightbox.min.js',
             'js/jquery.textarea.min.js',
-            'js/django_bootstrap_markdown_editor.js',
+            'js/django_bootstrap_markdown.js',
         )
+        css = {
+            'all': (
+                '//cdnjs.cloudflare.com/ajax/libs/ekko-lightbox/3.0.3a/ekko-lightbox.min.css',
+                'css/django_bootstrap_markdown.css',
+            )
+        }
